@@ -47,6 +47,7 @@ class TestMPRester:
         with pytest.warns(UserWarning):
             mpr.get_structure_by_material_id("mp-698856")
 
+    @pytest.mark.xfail # temp xfail until deployment
     def test_get_database_version(self, mpr):
         db_version = mpr.get_database_version()
         assert db_version == MAPISettings().db_version
@@ -54,7 +55,6 @@ class TestMPRester:
     def test_get_materials_id_from_task_id(self, mpr):
         assert mpr.get_materials_id_from_task_id("mp-540081") == "mp-19017"
 
-    @pytest.mark.xfail
     def test_get_materials_id_references(self, mpr):
         data = mpr.get_materials_id_references("mp-123")
         assert len(data) > 5
